#ifndef NT2_INCLUDE_FUNCTIONS_NORMRND_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_NORMRND_HPP_INCLUDED

#include <nt2/statistics/include/functions/normrnd.hpp>

#endif
